#
# spec file for package partclone
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2012 Mariusz Fik <fisiu@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           partclone
Version:        0.3.18
Release:        bp156.3.5
Summary:        File System Clone Utilities
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            https://partclone.org/
Source:         https://github.com/Thomas-Tsai/partclone/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  e2fsprogs-devel
BuildRequires:  fdupes
BuildRequires:  libbtrfs-devel
BuildRequires:  ncurses-devel
BuildRequires:  nilfs-utils-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(libntfs-3g)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(uuid)

%description
A set of file system clone utilities, including
ext2/3, reiserfs, reiser4, xfs, hfs+ file systems

%lang_package

%prep
%autosetup

%build
export CFLAGS="%{optflags} -fcommon"
autoreconf -fiv
%configure \
  --enable-ncursesw \
  --enable-fuse \
  --enable-fs-test \
  --enable-btrfs \
  --enable-extfs \
  --enable-fat \
  --enable-hfsp \
  --enable-apfs \
  --enable-ntfs \
  --enable-xfs \
  --enable-f2fs \
  --enable-nilfs2 \
  --enable-minix \
  --enable-exfat
# During build following occurs, but it seems harmless
# files fail-mbr.bin and fail-mbr.bin.orig differ significantly:
%make_build LIBS="-lncursesw -lpthread -lfuse" ||:

%install
%make_install INSTLIBDIR=%{buildroot}%{_datadir}/%{name}
%fdupes -s %{buildroot}%{_datadir}
%find_lang %{name}

%files
%license COPYING
%doc ChangeLog README.md
%{_sbindir}/partclone.apfs
%{_sbindir}/partclone.btrfs
%{_sbindir}/partclone.chkimg
%{_sbindir}/partclone.dd
%{_sbindir}/partclone.ext2
%{_sbindir}/partclone.ext3
%{_sbindir}/partclone.ext4
%{_sbindir}/partclone.ext4dev
%{_sbindir}/partclone.extfs
%{_sbindir}/partclone.exfat
%{_sbindir}/partclone.f2fs
%{_sbindir}/partclone.fat
%{_sbindir}/partclone.fat12
%{_sbindir}/partclone.fat16
%{_sbindir}/partclone.fat32
%{_sbindir}/partclone.imgfuse
%{_sbindir}/partclone.hfs+
%{_sbindir}/partclone.hfsp
%{_sbindir}/partclone.hfsplus
%{_sbindir}/partclone.imager
%{_sbindir}/partclone.info
%{_sbindir}/partclone.minix
%{_sbindir}/partclone.nilfs2
%{_sbindir}/partclone.ntfs
%{_sbindir}/partclone.ntfsfixboot
%{_sbindir}/partclone.ntfsreloc
%{_sbindir}/partclone.restore
%{_sbindir}/partclone.vfat
%{_sbindir}/partclone.xfs
%{_mandir}/man8/partclone.8%{?ext_man}
%{_mandir}/man8/partclone.btrfs.8%{?ext_man}
%{_mandir}/man8/partclone.chkimg.8%{?ext_man}
%{_mandir}/man8/partclone.dd.8%{?ext_man}
%{_mandir}/man8/partclone.ext2.8%{?ext_man}
%{_mandir}/man8/partclone.ext3.8%{?ext_man}
%{_mandir}/man8/partclone.ext4.8%{?ext_man}
%{_mandir}/man8/partclone.ext4dev.8%{?ext_man}
%{_mandir}/man8/partclone.extfs.8%{?ext_man}
%{_mandir}/man8/partclone.exfat.8%{?ext_man}
%{_mandir}/man8/partclone.f2fs.8%{?ext_man}
%{_mandir}/man8/partclone.fat.8%{?ext_man}
%{_mandir}/man8/partclone.fat12.8%{?ext_man}
%{_mandir}/man8/partclone.fat16.8%{?ext_man}
%{_mandir}/man8/partclone.fat32.8%{?ext_man}
%{_mandir}/man8/partclone.hfs+.8%{?ext_man}
%{_mandir}/man8/partclone.hfsp.8%{?ext_man}
%{_mandir}/man8/partclone.hfsplus.8%{?ext_man}
%{_mandir}/man8/partclone.imager.8%{?ext_man}
%{_mandir}/man8/partclone.info.8%{?ext_man}
%{_mandir}/man8/partclone.minix.8%{?ext_man}
%{_mandir}/man8/partclone.nilfs2.8%{?ext_man}
%{_mandir}/man8/partclone.ntfs.8%{?ext_man}
%{_mandir}/man8/partclone.ntfsfixboot.8%{?ext_man}
%{_mandir}/man8/partclone.ntfsreloc.8%{?ext_man}
%{_mandir}/man8/partclone.restore.8%{?ext_man}
%{_mandir}/man8/partclone.vfat.8%{?ext_man}
%{_mandir}/man8/partclone.xfs.8%{?ext_man}
%{_datadir}/partclone

%files lang -f %{name}.lang

%changelog
* Wed Sep 29 2021 Paolo Stivanin <info@paolostivanin.com>
- update to 0.3.18:
  * Add block_size and blocks_total in torrent.info to provide
    partition info
  * change C99 for loop init to C89 for compatibility
  * try to fix ignore_crc not working properly
* Mon Mar 22 2021 Martin Pluskal <mpluskal@suse.com>
- Drop dependency on libreiserfs
* Wed Mar 10 2021 Martin Pluskal <mpluskal@suse.com>
- Resolve build failure on Tumleweed
* Tue Dec 29 2020 Dirk Müller <dmueller@suse.com>
- update to 0.3.17:
  * fix progress
  * update btrfs to 5.4.1
  * fix crash when backing up swap partition
  * Ignore free space check if compression is enabled
* Mon Jul 27 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.3.15
  * XFS fixes
* Thu Jun 11 2020 Martin Pluskal <mpluskal@suse.com>
- Fix building with gcc10
* Thu Sep 26 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.3.13"
  * Add support for apfs
- Update download url
* Fri Dec 14 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.3.12:
  * Support compressed cloned images
- Enable exfat support
* Thu Oct 19 2017 mpluskal@suse.com
- Update to version 0.3.11 (boo#1130986):
  * update xfs
* Tue Feb 21 2017 mpluskal@suse.com
- Update to version 0.3.5a:
  * Support for fuse
  * Several bugfixes and internal changes
  * Resolves boo#1028904 CVE-2017-6596
* Sun Jul  3 2016 mpluskal@suse.com
- Update to version 0.2.89:
  * small bugfixes
* Sun Mar 20 2016 mpluskal@suse.com
- Switch to 0.2.88 (as 0.3 branch seems to be currently abandoned)
- Enable more filesystems
- Remove ppc excludes as build now succeeds
- Cleanup spec file
- Drop upstreamed partclone-missing-includes.patch
* Thu Aug 13 2015 normand@linux.vnet.ibm.com
- ExcludeArch:    ppc ppc64 ppc64le
  PowerPC do not support the fail-mbr/fail-mbr.S
* Wed Jun 24 2015 dimstar@opensuse.org
- Add partclone-missing-includes.patch: Fix build with GCC5 by
  correctly including the needed headers.
* Sat Mar 21 2015 mpluskal@suse.com
- Remove conditions that applied to old releases
* Wed Mar 18 2015 mpluskal@suse.com
- Update to 0.3.0~gitbcaa
  * for a full list of changes see attached Changelog
* Thu Oct  3 2013 fisiu@opensuse.org
- Update to 0.2.58:
  * ship failmbr
  * fixed jfs issues
  * fixed ncurses interface
  * updated doc and man pages
* Wed Nov  7 2012 fisiu@opensuse.org
- Update to 0.2.48:
  * fixed VMFS-5 and NTFS cloning
  * updated the ntfsfixboot version
  * memory usage optimized
  * updated man pages
- Build with support for btrfs, extfs, fat, hfsp, ntfs, reiserfs.
* Thu Apr 19 2012 highwaystar.ru@gmail.com
- update to 0.2.38
* Sun Sep 19 2010 highwaystar.ru@gmail.com
- built with ntfs support
- built with jfs support
* Fri Sep 17 2010 highwaystar.ru@gmail.com
- initial build for openSUSE
- not all filesystems supported yet
